@@ -7,9 +7,10 @@
 #' or four corner points that defines a rectangle (or a box), or a single coordinate. The default coordinate system used by CDL is a projected
 #' coordinate system called Albers projection (or Albers equal-area conic projection). Users could specify coordinates based on a
 #' different coordinate system (defined by the \code{crs} argument), including the geographic coordinate system such as latitude-longitude.
-#' @param year  Crop year of data to request. Should be a 4-digit numerical value.
+#' @param year  Year of data to request. Should be a 4-digit numerical value.
 #' @param type Type of AOI. 'f' for county, 'ps' for triangle with multiple coordinates, 'b' for box with four corner points, 'p' for a single coordinate.
 #' @param crs Coordinate system. NULL if use the default coordinate system (e.g., Albers projection); Use '+init=epsg:4326' for longitude/latitude.
+#' @param tol_time Number of seconds to wait for a response until giving up. Default is 20 seconds.
 #'
 #' @return
 #' The function returns a data frame that reports summary statistics of the CDL data for an area of interest in a given year.
@@ -31,13 +32,13 @@
 #' head(data, n = 5)
 #'}
 
-GetCDLStat <- function(aoi = NULL, year = NULL, type = 'f', crs = NULL){
+GetCDLStat <- function(aoi = NULL, year = NULL, type = NULL, crs = NULL, tol_time = 20){
   targetCRS <- "+proj=aea +lat_1=29.5 +lat_2=45.5 +lat_0=23 +lon_0=-96 +x_0=0 +y_0=0 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
 
   if(!type %in% c('f', 'ps', 'b', 'p')) stop('The type value is wrong.')
 
   if(type == 'f'){
-    data <- GetCDLStatF(fips = aoi, year = year)
+    data <- GetCDLStatF(fips = aoi, year = year, tol_time = tol_time)
   }
 
   if(type == 'ps'){
@@ -48,7 +49,7 @@ GetCDLStat <- function(aoi = NULL, year = NULL, type = 'f', crs = NULL){
       newpoints <- sp::spTransform(oldpoints, targetCRS)
       aoi <- paste0(as.vector(t(newpoints@coords)), collapse = ',')
     }
-    data <- GetCDLStatPs(points = aoi, year = year)
+    data <- GetCDLStatPs(points = aoi, year = year, tol_time = tol_time)
   }
 
   if(type == 'b'){
@@ -59,7 +60,7 @@ GetCDLStat <- function(aoi = NULL, year = NULL, type = 'f', crs = NULL){
       newpoints <- sp::spTransform(oldpoints, targetCRS)
       aoi <- paste0(as.vector(t(newpoints@coords)), collapse = ',')
     }
-    data <- GetCDLStatB(box = aoi, year = year)
+    data <- GetCDLStatB(box = aoi, year = year, tol_time = tol_time)
   }
   return(data)
 }
